==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/MechanicalleaseEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.MechanicalleasedetailEntity;
/**
 * 月度机械设备租赁单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_mechanicallease")
public class MechanicalleaseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 租赁商
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 租赁商名称
    @TableField(value="ex_tax_settlement")
    private java.math.BigDecimal exTaxSettlement; // 结算金额（除税）
    @TableField(value="in_tax_settlement")
    private java.math.BigDecimal inTaxSettlement; // 结算金额（含税）
    @TableField(value="settlement_time")
    private java.util.Date settlementTime; // 结算时间
    @TableField(value="billing_start_time")
    private java.util.Date billingStartTime; // 计费起始时间
    @TableField(value="billing_end_time")
    private java.util.Date billingEndTime; // 计费截止时间
    @TableField(value="ex_tax_this_month_total")
    private java.math.BigDecimal exTaxThisMonthTotal; // 本月合计(除税)
    @TableField(value="in_tax_this_month_total")
    private java.math.BigDecimal inTaxThisMonthTotal; // 本月合计(含税)
    @TableField(value="ex_tax_cumulative")
    private java.math.BigDecimal exTaxCumulative; // 累计发生(除税)
    @TableField(value="in_tax_cumulative")
    private java.math.BigDecimal inTaxCumulative; // 累计发生(含税)
    @TableField(value = "project_code")
    private java.lang.String projectCode;//项目编码

    @TableField(exist=false)
    @SubEntity(serviceName="mechanicalleasedetailService",pidName = "mid")
    private List<MechanicalleasedetailEntity> mechanicalleasedetailEntities = new ArrayList<>(); // 月度机械设备租赁单子表


    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    /**
     * 租赁商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 租赁商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 结算金额（除税）
     */
    public java.math.BigDecimal getExTaxSettlement() {
        return exTaxSettlement;
    }

    /**
     * 结算金额（除税）
     */
    public void setExTaxSettlement(java.math.BigDecimal exTaxSettlement) {
        this.exTaxSettlement = exTaxSettlement;
    }
    /**
     * 结算金额（含税）
     */
    public java.math.BigDecimal getInTaxSettlement() {
        return inTaxSettlement;
    }

    /**
     * 结算金额（含税）
     */
    public void setInTaxSettlement(java.math.BigDecimal inTaxSettlement) {
        this.inTaxSettlement = inTaxSettlement;
    }
    /**
     * 结算时间
     */
    public java.util.Date getSettlementTime() {
        return settlementTime;
    }

    /**
     * 结算时间
     */
    public void setSettlementTime(java.util.Date settlementTime) {
        this.settlementTime = settlementTime;
    }
    /**
     * 计费起始时间
     */
    public java.util.Date getBillingStartTime() {
        return billingStartTime;
    }

    /**
     * 计费起始时间
     */
    public void setBillingStartTime(java.util.Date billingStartTime) {
        this.billingStartTime = billingStartTime;
    }
    /**
     * 计费截止时间
     */
    public java.util.Date getBillingEndTime() {
        return billingEndTime;
    }

    /**
     * 计费截止时间
     */
    public void setBillingEndTime(java.util.Date billingEndTime) {
        this.billingEndTime = billingEndTime;
    }
    /**
     * 本月合计(除税)
     */
    public java.math.BigDecimal getExTaxThisMonthTotal() {
        return exTaxThisMonthTotal;
    }

    /**
     * 本月合计(除税)
     */
    public void setExTaxThisMonthTotal(java.math.BigDecimal exTaxThisMonthTotal) {
        this.exTaxThisMonthTotal = exTaxThisMonthTotal;
    }
    /**
     * 本月合计(含税)
     */
    public java.math.BigDecimal getInTaxThisMonthTotal() {
        return inTaxThisMonthTotal;
    }

    /**
     * 本月合计(含税)
     */
    public void setInTaxThisMonthTotal(java.math.BigDecimal inTaxThisMonthTotal) {
        this.inTaxThisMonthTotal = inTaxThisMonthTotal;
    }
    /**
     * 累计发生(除税)
     */
    public java.math.BigDecimal getExTaxCumulative() {
        return exTaxCumulative;
    }

    /**
     * 累计发生(除税)
     */
    public void setExTaxCumulative(java.math.BigDecimal exTaxCumulative) {
        this.exTaxCumulative = exTaxCumulative;
    }
    /**
     * 累计发生(含税)
     */
    public java.math.BigDecimal getInTaxCumulative() {
        return inTaxCumulative;
    }

    /**
     * 累计发生(含税)
     */
    public void setInTaxCumulative(java.math.BigDecimal inTaxCumulative) {
        this.inTaxCumulative = inTaxCumulative;
    }
    
    /**
     * 月度机械设备租赁单子表
     */
    public List<MechanicalleasedetailEntity> getMechanicalleasedetailEntities() {
        return mechanicalleasedetailEntities;
    }

    /**
     * 月度机械设备租赁单子表
     */
    public void setMechanicalleasedetailEntities(List<MechanicalleasedetailEntity> mechanicalleasedetailEntities) {
        this.mechanicalleasedetailEntities = mechanicalleasedetailEntities;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/bean/MechanicalleaseEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.MechanicalleasedetailEntity;
/**
 * 月度机械设备租赁单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_mechanicallease")
public class MechanicalleaseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="supplier_id")
    private java.lang.Long supplierId; // 租赁商
    @TableField(value="supplier_name")
    private java.lang.String supplierName; // 租赁商名称
    @TableField(value="ex_tax_settlement")
    private java.math.BigDecimal exTaxSettlement; // 结算金额（除税）
    @TableField(value="in_tax_settlement")
    private java.math.BigDecimal inTaxSettlement; // 结算金额（含税）
    @TableField(value="settlement_time")
    private java.util.Date settlementTime; // 结算时间
    @TableField(value="billing_start_time")
    private java.util.Date billingStartTime; // 计费起始时间
    @TableField(value="billing_end_time")
    private java.util.Date billingEndTime; // 计费截止时间
    @TableField(value="ex_tax_this_month_total")
    private java.math.BigDecimal exTaxThisMonthTotal; // 本月合计(除税)
    @TableField(value="in_tax_this_month_total")
    private java.math.BigDecimal inTaxThisMonthTotal; // 本月合计(含税)
    @TableField(value="ex_tax_cumulative")
    private java.math.BigDecimal exTaxCumulative; // 累计发生(除税)
    @TableField(value="in_tax_cumulative")
    private java.math.BigDecimal inTaxCumulative; // 累计发生(含税)
    @TableField(value = "project_code")
    private java.lang.String projectCode;//项目编码
    @TableField(value="save_time")
    private java.util.Date saveTime; // 保存时间
    @TableField(value="reference_code")
    private java.lang.String referenceCode; // 引用租赁单的汇总单code
    @TableField(value = "is_reference")
    private java.lang.Integer isReference; // 是否被汇总表引用(0:否，1:是)

    @TableField(exist=false)
    @SubEntity(serviceName="mechanicalleasedetailService",pidName = "mid")
    private List<MechanicalleasedetailEntity> mechanicalleasedetailEntities = new ArrayList<>(); // 月度机械设备租赁单子表

    public Integer getIsReference() {
        return isReference;
    }

    public void setIsReference(Integer isReference) {
        this.isReference = isReference;
    }

    public String getReferenceCode() {
        return referenceCode;
    }

    public void setReferenceCode(String referenceCode) {
        this.referenceCode = referenceCode;
    }

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    /**
     * 租赁商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 租赁商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 结算金额（除税）
     */
    public java.math.BigDecimal getExTaxSettlement() {
        return exTaxSettlement;
    }

    /**
     * 结算金额（除税）
     */
    public void setExTaxSettlement(java.math.BigDecimal exTaxSettlement) {
        this.exTaxSettlement = exTaxSettlement;
    }
    /**
     * 结算金额（含税）
     */
    public java.math.BigDecimal getInTaxSettlement() {
        return inTaxSettlement;
    }

    /**
     * 结算金额（含税）
     */
    public void setInTaxSettlement(java.math.BigDecimal inTaxSettlement) {
        this.inTaxSettlement = inTaxSettlement;
    }
    /**
     * 结算时间
     */
    public java.util.Date getSettlementTime() {
        return settlementTime;
    }

    /**
     * 结算时间
     */
    public void setSettlementTime(java.util.Date settlementTime) {
        this.settlementTime = settlementTime;
    }
    /**
     * 计费起始时间
     */
    public java.util.Date getBillingStartTime() {
        return billingStartTime;
    }

    /**
     * 计费起始时间
     */
    public void setBillingStartTime(java.util.Date billingStartTime) {
        this.billingStartTime = billingStartTime;
    }
    /**
     * 计费截止时间
     */
    public java.util.Date getBillingEndTime() {
        return billingEndTime;
    }

    /**
     * 计费截止时间
     */
    public void setBillingEndTime(java.util.Date billingEndTime) {
        this.billingEndTime = billingEndTime;
    }
    /**
     * 本月合计(除税)
     */
    public java.math.BigDecimal getExTaxThisMonthTotal() {
        return exTaxThisMonthTotal;
    }

    /**
     * 本月合计(除税)
     */
    public void setExTaxThisMonthTotal(java.math.BigDecimal exTaxThisMonthTotal) {
        this.exTaxThisMonthTotal = exTaxThisMonthTotal;
    }
    /**
     * 本月合计(含税)
     */
    public java.math.BigDecimal getInTaxThisMonthTotal() {
        return inTaxThisMonthTotal;
    }

    /**
     * 本月合计(含税)
     */
    public void setInTaxThisMonthTotal(java.math.BigDecimal inTaxThisMonthTotal) {
        this.inTaxThisMonthTotal = inTaxThisMonthTotal;
    }
    /**
     * 累计发生(除税)
     */
    public java.math.BigDecimal getExTaxCumulative() {
        return exTaxCumulative;
    }

    /**
     * 累计发生(除税)
     */
    public void setExTaxCumulative(java.math.BigDecimal exTaxCumulative) {
        this.exTaxCumulative = exTaxCumulative;
    }
    /**
     * 累计发生(含税)
     */
    public java.math.BigDecimal getInTaxCumulative() {
        return inTaxCumulative;
    }

    /**
     * 累计发生(含税)
     */
    public void setInTaxCumulative(java.math.BigDecimal inTaxCumulative) {
        this.inTaxCumulative = inTaxCumulative;
    }
    
    /**
     * 月度机械设备租赁单子表
     */
    public List<MechanicalleasedetailEntity> getMechanicalleasedetailEntities() {
        return mechanicalleasedetailEntities;
    }

    /**
     * 月度机械设备租赁单子表
     */
    public void setMechanicalleasedetailEntities(List<MechanicalleasedetailEntity> mechanicalleasedetailEntities) {
        this.mechanicalleasedetailEntities = mechanicalleasedetailEntities;
    }
}
